# Opening file from CLI is multiple times slower than with VSCode

**URL:** <https://forum.cursor.com/t/opening-file-from-cli-is-multiple-times-slower-than-with-vscode/59021>\
**Category:** Bug Reports\
**Created:** [March 4, 2025, 9:09am UTC](https://forum.cursor.com/t/opening-file-from-cli-is-multiple-times-slower-than-with-vscode/59021 "2025-03-04T09:09:36Z")\
**Posts on this page:** 2\
**Page:** 1

<div class="post-metadata">

**Author:** ![Jaakkonen](https://sea3.discourse-cdn.com/cursor1/user_avatar/forum.cursor.com/jaakkonen/32/11404_2.png) [@Jaakkonen](https://forum.cursor.com/u/Jaakkonen)\
**Post date:** [March 4, 2025, 9:09am UTC](https://forum.cursor.com/t/opening-file-from-cli-is-multiple-times-slower-than-with-vscode/59021/1 "2025-03-04T09:09:36Z")

</div>

✅ **Check the forum** to ensure the issue hasn’t been reported already

Couldn’t find

🐞 Provide a **clear description** of the bug

When using Cursor as `EDITOR=cursor` and trying to open files with it (in my case from my file manager), it takes really long. However with VSCode it’s 2x faster.

🔄 Explain how to **reproduce the bug** (if known)

```sh
$ touch /tmp/myfile
$ # Gives ~1.1s
$ hyperfine 'code -r /tmp/myfile'
$ # Gives ~2.2.s
$ hyperfine 'cursor -r /tmp/myfile'

```

💻 Tell us your operating system and your **Cursor version** (e.g., `Windows, 0.x.x`).

Arch Linux.

```sh
$ code --version
1.97.2
e54c774e0add60467559eb0d1e229c6452cf8447
x64
$ cursor --version
# Produces no output

```

🚫 Tell us if the issue stops you from using Cursor.

No but it’s really annoying

---

<div class="post-metadata">

**Author:** ![system](https://sea3.discourse-cdn.com/cursor1/user_avatar/forum.cursor.com/system/32/99069_2.png) [@system](https://forum.cursor.com/u/system)\
**Post date:** [April 3, 2025, 9:09am UTC](https://forum.cursor.com/t/opening-file-from-cli-is-multiple-times-slower-than-with-vscode/59021/2 "2025-04-03T09:09:56Z")

</div>

Closed on April 3, 2025, 9:09am UTC

This topic was automatically closed 30 days after the last reply. New replies are no longer allowed.
